summaryrefslogtreecommitdiff
path: root/spec/functional/rest_spec.rb
diff options
context:
space:
mode:
Diffstat (limited to 'spec/functional/rest_spec.rb')
-rw-r--r--spec/functional/rest_spec.rb15
1 files changed, 8 insertions, 7 deletions
diff --git a/spec/functional/rest_spec.rb b/spec/functional/rest_spec.rb
index 7c6b1872ef..14e76087c4 100644
--- a/spec/functional/rest_spec.rb
+++ b/spec/functional/rest_spec.rb
@@ -1,6 +1,6 @@
#
# Author:: Lamont Granquist (<lamont@getchef.com>)
# Copyright:: Copyright (c) 2014 Chef Software, Inc.
# License:: Apache License, Version 2.0
#
# Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,9 +16,9 @@
# limitations under the License.
#
-require 'spec_helper'
-require 'tiny_server'
-require 'support/shared/functional/http'
+require "spec_helper"
+require "tiny_server"
+require "support/shared/functional/http"
describe Chef::REST do
include ChefHTTPShared
@@ -80,13 +80,14 @@ describe Chef::REST do
before do
Chef::Config[:node_name] = "webmonkey.example.com"
Chef::Config[:client_key] = CHEF_SPEC_DATA + "/ssl/private_key.pem"
+ Chef::Config[:treat_deprecation_warnings_as_errors] = false
end
- before(:all) do
+ before(:each) do
start_tiny_server
end
- after(:all) do
+ after(:each) do
stop_tiny_server
end
@@ -1,6 +1,6 @@
#
-# Author:: Lamont Granquist (<lamont@getchef.com>)
-# Copyright:: Copyright (c) 2014 Chef Software, Inc.
+# Author:: Lamont Granquist (<lamont@chef.io>)
+# Copyright:: Copyright 2014-2016, Chef Software, Inc.
# License:: Apache License, Version 2.0
#